@@ -1,10 +1,10 @@
-import typer, requests, os, zipfile, glob, shutil, json, time
+import typer, requests, os, zipfile, glob, shutil, json
 from pathlib import Path
 import snow_pyrepl as pyrepl
 from typing import Optional
 from replit.database import Database
 
-__version__ = "1.1.3"
+__version__ = "1.1.4"
 homedir = Path.home()
 homedir = str(homedir).replace("\\", "/")
 try:
@@ -127,7 +127,7 @@ def push():
 				"UUID": uuid,
 				"SID": sid,
 				"filepath": newfile,
-				"content": open(newfile, "r").read()
+				"content": open(newfile, "rb").read().decode("ISO-8859-1")
 				}),
 				headers = {'Content-type': 'application/json', 'Accept': 'text/plain'})
 
@@ -427,5 +427,11 @@ Repls -
 	"""
 	typer.echo(text)
 
-if __name__ == "main":
-	app()
+@app.command()
+def pip(operation:str):
+	typer.echo(f"Running Operation: {operation}")
+	os.system(f"pip {operation}")
+	typer.echo("Updating pip config...")
+	os.system("pip freeze > requirements.txt")
+
+app()
